CmsFilterSearchEntry class

CmsFilterEntry for handling basic search

Inheritance

Constructors

CmsFilterSearchEntry({required List<String> filterKeys, required String entryKey, String? label, List<TextInputFormatter>? formatters, int flex = 4})

Properties

entryKey String
identity of CmsFilterEntry
final
filterKeys List<String>
  • filterKeys are paths to values to be filtered in the get function of CmsDelegate. It may be staggered e.g. user.data.image. To see how it works check JsonMapExtensions
  • final
    fixedLabel String
    Real display of the field. If null, last segment of key is displayed
    no setterinherited
    flex int
  • Defines size of the CmsFilterEntry in the CmsTable
  • final
    formatters List<TextInputFormatter>?
    final
    hashCode int
    The hash code for this object.
    no setterinherited
    label String?
  • label displays the name of the entry. To find out more check fixedLabel
  • final
    runtimeType Type
    A representation of the runtime type of the object.
    no setterinherited

    Methods

    buildField({required BuildContext context, required FutureOr<String>? value, required void onChanged(String? value)}) Widget
    Builder of the filter field. Recommended to be wrapped with CmsFieldWrapper
    override
    filterFromValues(JsonMap value) CmsFilter
    Builder of filters for CmsDelegate.
    override
    fromJson(Object? json) String?
    simple fromJson method, e.g. int.parse(json.toString) for an int value.
    inherited
    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    toJson(String? value) Object?
    simple toJson method, e.g. 12.toString for an int value.
    inherited
    toString() String
    A string representation of this object.
    inherited

    Operators

    operator ==(Object other) bool
    The equality operator.
    inherited