CmsFilterEntry<T> class
abstract
- CmsFilterEntry is an interface of a basic CmsTablePage filter component.
There are few basic entries already implemented: *CmsFilterSearchEntry for searching String values *CmsDateEntry for creating Date filter constraints
- Implementers
- Annotations
Constructors
Properties
- entryKey → String
-
identity of CmsFilterEntry
final
-
filterKeys
→ List<
String> -
- filterKeys are paths to values to be filtered in the get function of CmsDelegate. It may be staggered e.g.
user.data.image. To see how it works check JsonMapExtensionsfinal - filterKeys are paths to values to be filtered in the get function of CmsDelegate. It may be staggered e.g.
- fixedLabel → String
-
Real display of the field. If null, last segment of
keyis displayedno setter - flex → int
-
- Defines size of the CmsFilterEntry in the
CmsTablefinal - Defines size of the CmsFilterEntry in the
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
- label displays the name of the entry. To find out more check fixedLabel
final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildField(
{required BuildContext context, required T value, required void onChanged(T)}) → Widget - Builder of the filter field. Recommended to be wrapped with CmsFieldWrapper
-
filterFromValues(
JsonMap value) → CmsFilter - Builder of filters for CmsDelegate.
-
fromJson(
Object? json) → T? - simple fromJson method, e.g. int.parse(json.toString) for an int value.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
T value) → Object? - simple toJson method, e.g. 12.toString for an int value.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited